__all__ = (
    "__title__",
    "__description__",
    "__url__",
    "__version__",
    "__author__",
    "__author_email__",
    "__license__",
    "__copyright__",
)

__title__ = "biblebot"
__description__ = "Scraper for KBU students"
__url__ = "https://github.com/rekyungmin/biblebot-scraper"
__version__ = "0.1.5"
__author__ = "Kyungmin Lee"
__author_email__ = "rekyungmin@gmail.com"
__license__ = "MIT"
__copyright__ = "Copyright 2020 Kyungmin Lee"
